DiFuMo atlas


Notes
-----
1. We provide Dictionaries of Functional Modes “DiFuMo” that can serve as atlases to extract functional signals, eg to serve as IDPs, with different dimensionalities (64, 128, 256, 512, and 1024). These modes are optimized to represent well raw :term:`BOLD` timeseries, over a with range of experimental conditions.
               
    - All atlases are available in .nii.gz format and sampled to :term:`MNI` space
                     
2. Additionally, we provide meaningful names for these modes, based on their anatomical location, to facilitate reporting of results.

    - Anatomical names are available for each resolution in .csv

Content
-------
    :'maps': Nifti images with the (probabilistic) region definitions
    :'labels': CSV file specifying the label information


References
----------
For more information about this dataset's structure:
https://hal.inria.fr/hal-02904869

Dadi, K., Varoquaux, G., Machlouzarides-Shalit, A., Gorgolewski, KJ., Wassermann, D., Thirion, B., Mensch, A. Fine-grain atlases of functional modes for fMRI analysis. NeuroImage, Elsevier, 2020, pp.117126 [Link to this paper](https://hal.inria.fr/hal-02904869)


Mensch, A., Mairal, J., Thirion, B., Varoquaux, G., 2018. Stochastic Subsampling for Factorizing Huge Matrices. IEEE Transactions on Signal Processing 66, 113–128.

Poldrack, R.A., Barch, D.M., Mitchell, J.P., et al., 2013. Toward open sharing of task-based fMRI data: the OpenfMRI project. Frontiers in neuroinformatics 7.

Licence: usage is unrestricted for non-commercial research purposes.
